@@ -20,17 +20,6 @@
 
 #include "config.h"
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE
-#endif
-
-#include <errno.h>
-#include <fcntl.h>
-#include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-
 #include <glib/gstdio.h>
 
 #include <tiffio.h>
@@ -90,15 +79,6 @@ typedef struct {
 	gchar *orientation;
 } TiffData;
 
-static void extract_tiff (const gchar          *filename,
-                          TrackerSparqlBuilder *preupdate,
-                          TrackerSparqlBuilder *metadata);
-
-static TrackerExtractData extract_data[] = {
-	{ "image/tiff", extract_tiff },
-	{ NULL, NULL }
-};
-
 static void
 tiff_data_free (TiffData *tags)
 {
@@ -263,10 +243,12 @@ tag_to_string (TIFF    *image,
 	return NULL;
 }
 
-static void
-extract_tiff (const gchar          *uri,
-              TrackerSparqlBuilder *preupdate,
-              TrackerSparqlBuilder *metadata)
+G_MODULE_EXPORT gboolean
+tracker_extract_get_metadata (const gchar          *uri,
+                              const gchar          *mimetype,
+                              TrackerSparqlBuilder *preupdate,
+                              TrackerSparqlBuilder *metadata,
+                              GString              *where)
 {
 	TIFF *image;
 	TrackerXmpData *xd = NULL;
@@ -279,8 +261,6 @@ extract_tiff (const gchar          *uri,
 	glong exif_offset;
 	GPtrArray *keywords;
 	guint i;
-	GString *where = NULL;
-	int fd;
 
 #ifdef HAVE_LIBIPTCDATA
 	gchar *iptc_offset;
@@ -294,24 +274,10 @@ extract_tiff (const gchar          *uri,
 
 	filename = g_filename_from_uri (uri, NULL, NULL);
 
-	fd = g_open (filename, O_RDONLY | O_NOATIME, 0);
-	if (fd == -1 && errno == EPERM) {
-		fd = g_open (filename, O_RDONLY, 0);
-	}
-
-	if (fd == -1) {
-		g_warning ("Could not open tiff file '%s': %s\n",
-		           filename,
-		           g_strerror (errno));
-		g_free (filename);
-		return;
-	}	
-
-	if ((image = TIFFFdOpen (fd, filename, "r")) == NULL){
+	if ((image = TIFFOpen (filename, "r")) == NULL){
 		g_warning ("Could not open image:'%s'\n", filename);
 		g_free (filename);
-		close (fd);
-		return;
+		return FALSE;
 	}
 
 	tracker_sparql_builder_predicate (metadata, "a");
@@ -505,10 +471,6 @@ extract_tiff (const gchar          *uri,
 		tracker_sparql_builder_object_unvalidated (metadata, xd->license);
 	}
 
-        if (xd->regions) {
-	        tracker_xmp_apply_regions (preupdate, metadata, NULL, xd);
-        }
-
 	if (md.address || md.state || md.country || md.city ||
 	    md.gps_altitude || md.gps_latitude || md.gps_longitude) {
 
@@ -622,10 +584,6 @@ extract_tiff (const gchar          *uri,
 		tracker_sparql_builder_predicate (metadata, "nao:hasTag");
 		tracker_sparql_builder_object_variable (metadata, var);
 
-		if (where == NULL) {
-			where = g_string_new ("} } WHERE { {\n");
-		}
-
 		g_string_append_printf (where, "?%s a nao:Tag ; nao:prefLabel \"%s\" .\n", var, escaped);
 
 		g_free (var);
@@ -791,19 +749,10 @@ extract_tiff (const gchar          *uri,
 		tracker_sparql_builder_object_double (metadata, value);
 	}
 
-	if (where != NULL) {
-		tracker_sparql_builder_append (metadata, where->str);
-		g_string_free (where, TRUE);
-	}
-
 	tiff_data_free (&td);
 	tracker_exif_free (ed);
 	tracker_xmp_free (xd);
 	tracker_iptc_free (id);
-}
 
-TrackerExtractData *
-tracker_extract_get_data (void)
-{
-	return extract_data;
+	return TRUE;
 }
