@@ -45,6 +45,9 @@ TRACKER_EXTRACT_IFACE = "org.freedesktop.Tracker1.Extract"
 
 WRITEBACK_BUSNAME = "org.freedesktop.Tracker1.Writeback"
 
+
+DCONF_MINER_SCHEMA = "org.freedesktop.Tracker.Miner.Files"
+
 def expandvars (variable):
     # Note: the order matters!
     result = variable
@@ -76,7 +79,7 @@ DATADIR = os.path.normpath (expandvars (RAW_DATA_DIR))
 BINDIR = os.path.normpath (expandvars (RAW_BINDIR))
                             
 haveMaemo = ("#" == "")
-haveUpstart = ("#" == "")
+haveUpstart = ("" == "")
 disableJournal = ("#" == "")
 
 TEST_TMP_DIR = os.path.join (os.environ["HOME"], ".tracker-tests")
