@@ -26,9 +26,6 @@ from dbus.mainloop.glib import DBusGMainLoop
 import configuration as cfg
 import re
 
-class NoMetadataException (Exception):
-    pass
-
 class StoreHelper:
     """
     Wrapper for the Store API
@@ -181,18 +178,15 @@ class ExtractorHelper ():
          }
         """
         metadata = {}
-        try:
-            preupdate, embedded = self.extractor.GetMetadata (filename, mime)
-            for attribute_value in self.__process_lines (embedded):
-                att, value = attribute_value.split (" ", 1)
-                if metadata.has_key (att):
-                    metadata [att].append (value)
-                else:
-                    metadata [att] = [value]
+        preupdate, embedded, where = self.extractor.GetMetadata (filename, mime)
+        for attribute_value in self.__process_lines (embedded):
+            att, value = attribute_value.split (" ", 1)
+            if metadata.has_key (att):
+                metadata [att].append (value)
+            else:
+                metadata [att] = [value]
 
-            return metadata
-        except dbus.DBusException, e:
-            raise NoMetadataException ()
+        return metadata
             
     def __process_lines (self, embedded):
         """
@@ -209,19 +203,7 @@ class ExtractorHelper ():
         grouped_lines = []
         current_line = ""
         anon_node_open = False
-
-        pieces = embedded.split ("\n} } WHERE { {\n")
-        if len (pieces) == 1:
-            main = pieces [0]
-            tags = []
-        elif len (pieces) == 2:
-            main = pieces [0]
-            tags = pieces [1]
-        else:
-            print "Warning: something fishy splitting", embedded
- 
-        
-        for l in main.split ("\n\t"):
+        for l in embedded.split ("\n\t"):
             if "[" in l:
                 current_line = current_line + l
                 anon_node_open = True
@@ -244,34 +226,14 @@ class ExtractorHelper ():
                 final_lines = self.__handle_multivalues (l.strip ())
                 grouped_lines = grouped_lines + final_lines
 
-        if len (tags) > 0:
-            grouped_lines += self.__handle_tags (tags)
-
-
         return map (self.__clean_value, grouped_lines)
 
-    def __process_where_part (self, where):
-        gettags = re.compile ("(\?\w+)\ a\ nao:Tag\ ;\ nao:prefLabel\ \"([\w\ -]+)\"")
-        tags = {}
-        for l in where.split ("\n"):
-            if len (l) == 0:
-                continue
-            match = gettags.search (l)
-            if (match):
-                tags [match.group(1)] = match.group (2)
-            else:
-                print "This line is not a tag:", l
-
-        return tags
-
     def __handle_multivalues (self, line):
         """
         Split multivalues like:
         a nfo:Image, nmm:Photo ;
            -> a nfo:Image ;
            -> a nmm:Photo ;
-
-        IGNORE hasTag
         """
         hasEscapedComma = re.compile ("\".+,.+\"")
 
@@ -282,8 +244,6 @@ class ExtractorHelper ():
                 results.append ("%s %s" % (prop, value.strip ()))
             return results
         else:
-            if "nao:hasTag" in line:
-                return []
             return [line]
         
 
@@ -304,8 +264,19 @@ class ExtractorHelper ():
 
         """
         
+        # hasTag case
+        if line.startswith ("nao:hasTag"):
+            getlabel = re.compile ("nao:prefLabel\ \"([\w\ -]+)\"")
+            match = getlabel.search (line)
+            if (match):
+                line = 'nao:hasTag:prefLabel "%s" ;' % (match.group(1))
+                return [line]
+            else:
+                print "Whats wrong on line", line, "?"
+                return [line]
+
         # location case
-        if line.startswith ("slo:location"):
+        elif line.startswith ("slo:location"):
             results = []
 
             # Can have country AND/OR city
@@ -354,22 +325,6 @@ class ExtractorHelper ():
                 print " *** Something special in this line '%s'" % (entry)
         return results
 
-
-    def __handle_tags (self, sparql):
-        results = []
-        gettag = re.compile ('a nao:Tag\ ;\ nao:prefLabel "([\w:-]+)"')
-        for l in sparql.split ("\n"):
-            if len (l) < 1:
-                continue
-            tag_match = gettag.search (l)
-            if (tag_match):
-                results.append ("nao:hasTag:prefLabel %s ;" % tag_match.group (1))
-            else:
-                print " *** Something special in this tag line '%s'" % (l)
-            
-        return results
-
-
     def __clean_value (self, value):
         """
         the value comes with a ';' or a '.' at the end
